@@ -69,6 +69,9 @@ display_key_press_cb(GtkWidget *widget, GdkEventKey *event, MathDisplay *display
     /* Treat keypad keys as numbers even when numlock is off */
     switch(event->keyval)
     {
+    case GDK_KEY_KP_Delete: /* Period without numlock */
+        new_keyval = GDK_KEY_KP_Decimal;
+        break;
     case GDK_KEY_KP_Insert:
         new_keyval = GDK_KEY_0;
         break;
@@ -326,7 +329,7 @@ create_gui(MathDisplay *display)
     int i;
     GtkStyle *style;
 
-    main_box = gtk_vbox_new(FALSE, 0);
+    main_box = gtk_box_new(GTK_ORIENTATION_VERTICAL, 0);
     gtk_container_add(GTK_CONTAINER(display), main_box);
 
     g_signal_connect(display, "key-press-event", G_CALLBACK(key_press_cb), display);
@@ -350,7 +353,7 @@ create_gui(MathDisplay *display)
     g_signal_connect(display->priv->text_view, "key-press-event", G_CALLBACK(display_key_press_cb), display);
     gtk_box_pack_start(GTK_BOX(main_box), display->priv->text_view, TRUE, TRUE, 0);
 
-    info_box = gtk_hbox_new(FALSE, 6);
+    info_box = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 6);
     gtk_box_pack_start(GTK_BOX(main_box), info_box, FALSE, TRUE, 0);
 
     info_view = gtk_text_view_new();
